*species*
=========

.. image:: https://badge.fury.io/py/species.svg
    :target: https://badge.fury.io/py/species

.. image:: https://img.shields.io/badge/Python-3.6%2C%203.7-yellow.svg?style=flat
    :target: https://pypi.python.org/pypi/species

.. image:: https://travis-ci.org/tomasstolker/species.svg?branch=master
    :target: https://travis-ci.org/tomasstolker/species

.. image:: https://readthedocs.org/projects/species/badge/?version=latest
    :target: http://species.readthedocs.io/en/latest/?badge=latest

.. image:: https://coveralls.io/repos/github/tomasstolker/species/badge.svg
   :target: https://coveralls.io/github/tomasstolker/species

.. image:: https://www.codefactor.io/repository/github/tomasstolker/species/badge
   :target: https://www.codefactor.io/repository/github/tomasstolker/species

.. image:: https://img.shields.io/badge/license-MIT-blue.svg?style=flat
    :target: https://github.com/tomasstolker/species/blob/master/LICENSE

.. image:: https://img.shields.io/badge/arXiv-1912.13316-orange.svg?style=flat
    :target: https://arxiv.org/abs/1912.13316

*species* is a toolkit for atmospheric characterization of exoplanets and brown dwarfs. It provides a coherent framework for spectral and photometric analysis which builds on publicly-available data from various resources such as spectral and photometric libraries, atmospheric models, evolutionary models, photometry of directly imaged planets, and filter transmission profiles. All data are stored in a central database and there are tools available for extracting, inspecting, analyzing, and plotting of data, models, and results. The package has been released on `PyPI <https://pypi.org/project/species/>`_ and is actively developed and maintained on Github.

Documentation
-------------

Documentation can be found at `http://species.readthedocs.io <http://species.readthedocs.io>`_.

Attribution
-----------

Please cite `Stolker et al. (2020) <https://ui.adsabs.harvard.edu/abs/2019arXiv191213316S/abstract/>`_ whenever results from *species* are used in a publication. Please also make sure to give credit to the relevant papers regarding the use of the publicly available data that *species* benefits from. The *species* logo is `available <https://people.phys.ethz.ch/~stolkert/species/species_logo.zip>`_ for use in presentations.

Contributing
------------

Contributions are welcome, please consider forking the repository and creating a pull request. Bug reports can be provided by creating an `issue <https://github.com/tomasstolker/species/issues>`_ on the Github page.

License
-------

Copyright 2018-2020 Tomas Stolker

*species* is distributed under the MIT License. See the LICENSE file for the terms and conditions.
